==> python3_core_api_client-0.3-py3-none-any.whl: cyberfusion/CoreApiClient/resources/malwares.py <==
from cyberfusion.CoreApiClient import models
from typing import Optional, List

from cyberfusion.CoreApiClient.interfaces import Resource


class Malwares(Resource):
    def list_malwares(
        self,
        *,
        skip: Optional[int] = None,
        limit: Optional[int] = None,
        filter_: Optional[List[str]] = None,
        sort: Optional[List[str]] = None,
    ) -> list[models.MalwareResource]:
        return [
            models.MalwareResource.construct(**model)
            for model in self.api_connector.send_or_fail(
                "GET",
                "/api/v1/malwares",
                data=None,
                query_parameters={
                    "skip": skip,
                    "limit": limit,
                    "filter": filter_,
                    "sort": sort,
                },
            ).json
        ]

    def list_malwares_for_unix_users(
        self,
        *,
        unix_user_id: int,
        skip: Optional[int] = None,
        limit: Optional[int] = None,
        filter_: Optional[List[str]] = None,
        sort: Optional[List[str]] = None,
    ) -> list[models.MalwareResource]:
        return [
            models.MalwareResource.construct(**model)
            for model in self.api_connector.send_or_fail(
                "GET",
                f"/api/v1/malwares/{unix_user_id}",
                data=None,
                query_parameters={
                    "skip": skip,
                    "limit": limit,
                    "filter": filter_,
                    "sort": sort,
                },
            ).json
        ]

==> python3_core_api_client-1.0.1-py3-none-any.whl: cyberfusion/CoreApiClient/resources/malwares.py <==
from cyberfusion.CoreApiClient import models
from typing import Optional, List

from cyberfusion.CoreApiClient.interfaces import Resource


class Malwares(Resource):
    def list_malwares(
        self,
        *,
        skip: Optional[int] = None,
        limit: Optional[int] = None,
        filter_: Optional[List[str]] = None,
        sort: Optional[List[str]] = None,
    ) -> list[models.MalwareResource]:
        return [
            models.MalwareResource.parse_obj(model)
            for model in self.api_connector.send_or_fail(
                "GET",
                "/api/v1/malwares",
                data=None,
                query_parameters={
                    "skip": skip,
                    "limit": limit,
                    "filter": filter_,
                    "sort": sort,
                },
            ).json
        ]

    def list_malwares_for_unix_users(
        self,
        *,
        unix_user_id: int,
        skip: Optional[int] = None,
        limit: Optional[int] = None,
        filter_: Optional[List[str]] = None,
        sort: Optional[List[str]] = None,
    ) -> list[models.MalwareResource]:
        return [
            models.MalwareResource.parse_obj(model)
            for model in self.api_connector.send_or_fail(
                "GET",
                f"/api/v1/malwares/{unix_user_id}",
                data=None,
                query_parameters={
                    "skip": skip,
                    "limit": limit,
                    "filter": filter_,
                    "sort": sort,
                },
            ).json
        ]
